@@ -15,15 +15,15 @@ print.PowANOVADat <- function(x, digits = 4, ...) {
   if (!inherits(x, "PowANOVADat"))
     stop("Use only with 'PowANOVADat' xs.\n")
 
-  cat("Power analysis based on pilot data\n\n")
-  cat("An ANOVA mixed effects model was fitted\n")
-  cat("Summary of parameter estimates from the pilot data:\n")
+  cat("Parameter estimates based on the pilot data:\n")
   cat("Treatment effect (beta):", round(x$beta, digits), "\n")
   cat("Variance of random effect (tau2):", round(x$tau2, digits), "\n")
   cat("Random error variance (sigma2):", round(x$sigma2, digits), "\n")
-  cat("The above parameter estimates are used as priori for Monte Carlo data generation from a ANOVA mixed effects model to estimate the power.\n")
-  cat("The estimated power for each combination of number of PDX lines (n) and number of mice per arm per PDX line (m) is calculated as the proportion of rejecting the null hypothesis beta = 0.\n")
-  cat("The summary of power across all possible combinations of n and m is shown below.\n\n")
+  cat("Monte Carlo power estimate, calculated as the
+  proportion of instances where the null hypothesis
+  H_0: beta = 0 is rejected (n = number of PDX lines,
+  m = number of animals per arm per PDX line,
+  N = total number of animals for a given combination of n and m).\n\n")
   print(x$PowTab)
 
 }
